@@ -398,7 +398,17 @@ public:
      * Sets the status of the BiDi rendering inside the terminal display.
      * Defaults to disabled.
      */
-    void setBidiEnabled(bool set) { _bidiEnabled=set; }
+    void setBidiEnabled(bool set) {
+        _bidiEnabled=set;
+        // See bug 280896 for more info
+#if QT_VERSION >= 0x040800
+        if (_bidiEnabled) {
+            setLineSpacing(0);
+        } else {
+            setLineSpacing(2);
+        }
+#endif
+    }
     /**
      * Returns the status of the BiDi rendering in this widget.
      */
